@@ -661,7 +661,7 @@ void cid_calls_merge(session_t *session) {
   char *cidstr; /* time of cid_list entry */
   size_t linelength = 100; /* buffer size */ 
   char *line = (char *) malloc (linelength); /* initial buffer for getline() */
-  FILE *f;
+  FILE *f = NULL;
 
   char from[41]; /* data to read from calls file */
   char to[41];
@@ -677,10 +677,15 @@ void cid_calls_merge(session_t *session) {
   GdkBitmap *bitmap;
 
   char *cache; /* tracks successive dates */
-  
+
+  char* calls_filename;
   
   /* try to find isdnlog data file */
-  if ((f = fopen(ISDN_ISDNLOG_FILE, "r"))) {
+  calls_filename = isdn_get_calls_filename();
+  if (calls_filename && (f = fopen(calls_filename, "r"))) {
+    if (debug) {
+      fprintf(stderr, "Using %s as source for isdnlog data.\n", calls_filename);
+    }
     /* do a binary search on the file for the desired starting time if needed */
     if (session->option_calls_merge_max_days) {
       low = 0;
@@ -781,10 +786,10 @@ void cid_calls_merge(session_t *session) {
     cid_normalize(session);
   
     if (fclose(f))
-      fprintf(stderr, "Error closing " ISDN_ISDNLOG_FILE ".\n");
+      fprintf(stderr, "Error closing %s.\n", calls_filename);
   } else { /* error on fopen() */
-    fprintf(stderr, "Warning: Couldn't open " ISDN_ISDNLOG_FILE
-	". Proceeding without it.\n");
+    fprintf(stderr, "Warning: Couldn't open %s. Proceeding without it.\n",
+	    calls_filename);
   }
   free(line);
 }
