@@ -34,6 +34,7 @@
 #include "session.h"
 #include "isdn.h"
 #include "util.h"
+#include "callerid.h"
 
 /* graphical symbols */
 #include "backspace.xpm"
@@ -213,6 +214,8 @@ static void controlpad_button_cb(GtkWidget *button, gpointer data) {
     }
     gtk_widget_grab_focus(GTK_WIDGET(GTK_COMBO(session->dial_number_box)
 				     ->entry));
+    gtk_entry_set_position(GTK_ENTRY(GTK_COMBO(session->dial_number_box)
+                                          ->entry), -1);
     break;
   case STATE_CONVERSATION: /* touchtones */
     if ((*c >= '0' && *c <= '9') || *c == '*' || *c == '#') { /* new tt */
@@ -254,16 +257,19 @@ static void controlpad_record_cb(GtkWidget *button, gpointer data) {
   if (button == session->record_checkbutton) {
     if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(button))) { /* record! */
       session->option_record = 1;
-      if (session->state == STATE_CONVERSATION)
+      if (session->state == STATE_CONVERSATION) {
 	if (recording_open(session->recorder,
-	      		   digits = util_digitstime(&session->ring_time),
-			   session->option_recording_format)) {
+	      		   digits = util_digitstime(&session->vcon_time),
+			   session->option_recording_format))
+	{
           fprintf(stderr, "Error opening audio file.\n");
 	  gtk_toggle_button_set_active(GTK_TOGGLE_BUTTON(
 				       session->record_checkbutton), FALSE);
 	  return;
 	}
         free(digits);
+	cid_row_mark_record(session, session->cid_num - 1);
+      }
     } else { /* don't record! */
       session->option_record = 0;
       if (session->state == STATE_CONVERSATION) {
