@@ -53,6 +53,14 @@
 #include "hangup.xpm"
 #include "pickup.xpm"
 #include "aboutlogo.xpm"
+/*
+#include "icon16x16.xpm"
+#include "icon32x32.xpm"
+*/
+#include "icon48x48.xpm"
+/*
+#include "icon64x64.xpm"
+*/
 
 /* call timeout_callback each <this number> of milliseconds */
 #define TIMER_DELAY 300
@@ -648,6 +656,8 @@ GtkWidget *get_dial_box(session_t *session) {
  * returns int to be returned from main()
  */
 int main_gtk(session_t *session) {
+  GList* icon_list = NULL;
+  
   GtkWidget *main_window;
   GtkWidget *main_vbox;
   GtkWidget *main_menu;
@@ -665,6 +675,20 @@ int main_gtk(session_t *session) {
   session->main_window = main_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title(GTK_WINDOW(main_window), "ANT " VERSION);
 
+  /* seems to cause window managers only to use the first one as icon (e.g.FVWM)
+  icon_list = g_list_append(icon_list,
+          (gpointer) gdk_pixbuf_new_from_xpm_data((const char**) icon16x16));
+  icon_list = g_list_append(icon_list,
+          (gpointer) gdk_pixbuf_new_from_xpm_data((const char**) icon32x32));
+  */
+  icon_list = g_list_append(icon_list,
+          (gpointer) gdk_pixbuf_new_from_xpm_data((const char**) icon48x48));
+  /*
+  icon_list = g_list_append(icon_list,
+          (gpointer) gdk_pixbuf_new_from_xpm_data((const char**) icon64x64));
+  */
+  gtk_window_set_icon_list(GTK_WINDOW(session->main_window), icon_list);
+  
   gtk_signal_connect(GTK_OBJECT(main_window), "delete_event",
 		     GTK_SIGNAL_FUNC(delete_event), (gpointer) session);
 
