@@ -750,7 +750,8 @@ void session_effect_callback(gpointer data,
                              gint source _U_, GdkInputCondition condition _U_)
 {
   session_t *session = (session_t *) data;
-  int i = 0; /* position in raw byte output buffer */
+  int pos = 0; /* position in raw byte output buffer */
+  int i;
   int index_out = 0; /* logical position (sample number) in output buffer */
   unsigned char x; /* generated ulaw sample */
   int just_read = 0;
@@ -763,33 +764,45 @@ void session_effect_callback(gpointer data,
     just_read = sf_readf_short(session->effect_sndfile,
 	session->effect_sndfile_buffer, session->effect_sndfile_buffer_frames);
   }
+  for (i = 0; i < session->effect_sfinfo.channels; i++)
+    session->effect_sndfile_buffer[session->effect_sndfile_buffer_frames *
+      session->effect_sfinfo.channels + i] =
+      session->effect_sndfile_buffer[(session->effect_sndfile_buffer_frames-1) *
+      session->effect_sfinfo.channels + i];
   
   /* fill buffer */
-  while (i < session->fragment_size_out) {
+  while (pos < session->fragment_size_out) {
     if (session->effect == EFFECT_SOUNDFILE) {
       double sum = 0.0;
       double leftbound = speed_factor * index_out; /* sndfile bounds */
       double rightbound = speed_factor * (index_out + 1);
+      double dummy;
+      double frac = modf(leftbound, &dummy);
       
-      do {
-        int frame_sum = 0;
-	double weight = (rightbound < floor(leftbound + 1) ?
-	    rightbound : floor(leftbound + 1)) - leftbound;
+      while (leftbound < rightbound) {
+        double frame_sum = 0;
+	double weight;
+	if (rightbound - leftbound < 1.0)
+	  weight = rightbound - leftbound;
+	else
+	  weight = 1.0;
 	  
         sndfile_buffer_index = (int)leftbound;
         if (sndfile_buffer_index < just_read) {
           int t_count;
           for (t_count=0; t_count < session->effect_sfinfo.channels; t_count++){
-	    frame_sum += (int) session->effect_sndfile_buffer[
-	      sndfile_buffer_index * session->effect_sfinfo.channels + t_count];
+	    frame_sum += (1.0 - frac) * session->effect_sndfile_buffer[
+	      sndfile_buffer_index * session->effect_sfinfo.channels + t_count]
+	               + frac * session->effect_sndfile_buffer[
+	      (sndfile_buffer_index+1)*session->effect_sfinfo.channels+t_count];
           }
           frame_sum /= session->effect_sfinfo.channels;
         } else {
 	  frame_sum = 0;
         }
 	sum += weight * frame_sum;
-	leftbound = floor(leftbound + 1);
-      } while (leftbound < rightbound);
+	leftbound += 1.0;
+      }
       sum /= speed_factor;
       x = session->audio_LUT_generate[(int)sum / 256 + 128];
     } else {
@@ -797,10 +810,10 @@ void session_effect_callback(gpointer data,
       x = fxgenerate(session, session->effect, 0, seconds);
     }
     if (session->audio_sample_size_out == 1) {
-      session->audio_outbuf[i++] = session->audio_LUT_in[(int)x];
+      session->audio_outbuf[pos++] = session->audio_LUT_in[(int)x];
     } else { /* audio_sample_size == 2 */
-      session->audio_outbuf[i++] = session->audio_LUT_in[(int)x * 2];
-      session->audio_outbuf[i++] = session->audio_LUT_in[(int)x * 2 + 1];
+      session->audio_outbuf[pos++] = session->audio_LUT_in[(int)x * 2];
+      session->audio_outbuf[pos++] = session->audio_LUT_in[(int)x * 2 + 1];
     }
     index_out ++;
     session->effect_pos++;
@@ -845,7 +858,8 @@ void session_effect_start(session_t *session, enum effect_t kind) {
       session->fragment_size_out / session->audio_sample_size_out *
       session->effect_sfinfo.samplerate / session->audio_speed_out;
     session->effect_sndfile_buffer = (short*) malloc (sizeof(short) *
-      session->effect_sndfile_buffer_frames * session->effect_sfinfo.channels);
+      (session->effect_sndfile_buffer_frames + 1) * /* doubled dummy at end */
+      session->effect_sfinfo.channels);
 
   }
   session->effect_tag = gtk_input_add_full(session->audio_fd_out,
