@@ -331,3 +331,34 @@ char* filename_extension(char* fn) {
   return result;
 }
 
+/*
+ * saves the current codeset globally for further calls to output_codeset_set()
+ * -> returns 0 on success, -1 otherwise (default: sets codeset to "UTF-8")
+ */
+static char* output_codeset = NULL; /* the saved codeset */
+int output_codeset_save() {
+  if (!(output_codeset = bind_textdomain_codeset(PACKAGE, NULL))) {
+    output_codeset = strdup("UTF-8");
+    return -1;
+  } else {
+    output_codeset = strdup(output_codeset);
+    return 0;
+  }
+}
+
+/*
+ * sets the output codeset GNU gettext produces while translating messages
+ * if codeset == 0, a saved values will be used.
+ * (save with: output_codeset_save())
+ * -> returns 0 on success, -1 otherwise
+ */
+int output_codeset_set(char* codeset) {
+  if (!codeset)
+    codeset = output_codeset;
+  if (!bind_textdomain_codeset(PACKAGE, codeset)) {
+    fprintf(stderr, "Error setting gettext output codeset to %s.\n", codeset);
+    return -1;
+  }
+  return 0;
+}
+
